@@ -22,9 +22,8 @@ module.
     See the License for the specific language governing permissions
     and limitations under the License.
 """
-from __future__ import unicode_literals
 
-__version__ = '3.1'
+__version__ = '[library version:2.2.5]'[17:-1]
 
 __all__ = [
     'association',
@@ -42,4 +41,15 @@ __all__ = [
     'store',
     'urinorm',
     'yadis',
-]
+    ]
+
+# Parse the version info
+try:
+    version_info = list(map(int, __version__.split('.')))
+except ValueError:
+    version_info = (None, None, None)
+else:
+    if len(version_info) != 3:
+        version_info = (None, None, None)
+    else:
+        version_info = tuple(version_info)
