@@ -117,6 +117,7 @@ From 1.1 to 2.0
 """
 
 import time, warnings
+import logging
 from copy import deepcopy
 
 from openid import cryptutil
@@ -420,7 +421,7 @@ class AssociateRequest(OpenIDRequest):
         if message.isOpenID1():
             session_type = message.getArg(OPENID_NS, 'session_type')
             if session_type == 'no-encryption':
-                oidutil.log('Received OpenID 1 request with a no-encryption '
+                logging.warn('Received OpenID 1 request with a no-encryption '
                             'assocaition session type. Continuing anyway.')
             elif not session_type:
                 session_type = 'no-encryption'
@@ -438,7 +439,7 @@ class AssociateRequest(OpenIDRequest):
 
         try:
             session = session_class.fromMessage(message)
-        except ValueError, why:
+        except ValueError as why:
             raise ProtocolError(message, 'Error parsing %s session: %s' %
                                 (session_class.session_type, why[0]))
 
@@ -1170,15 +1171,15 @@ class Signatory(object):
         """
         assoc = self.getAssociation(assoc_handle, dumb=True)
         if not assoc:
-            oidutil.log("failed to get assoc with handle %r to verify "
+            logging.error("failed to get assoc with handle %r to verify "
                         "message %r"
                         % (assoc_handle, message))
             return False
 
         try:
             valid = assoc.checkMessageSignature(message)
-        except ValueError, ex:
-            oidutil.log("Error in verifying %s with %s: %s" % (message,
+        except ValueError as ex:
+            logging.exception("Error in verifying %s with %s: %s" % (message,
                                                                assoc,
                                                                ex))
             return False
@@ -1225,7 +1226,7 @@ class Signatory(object):
 
         try:
             signed_response.fields = assoc.signMessage(signed_response.fields)
-        except kvform.KVFormError, err:
+        except kvform.KVFormError as err:
             raise EncodingError(response, explanation=str(err))
         return signed_response
 
@@ -1285,7 +1286,7 @@ class Signatory(object):
             key = self._normal_key
         assoc = self.store.getAssociation(key, assoc_handle)
         if assoc is not None and assoc.expiresIn <= 0:
-            oidutil.log("requested %sdumb key %r is expired (by %s seconds)" %
+            logging.info("requested %sdumb key %r is expired (by %s seconds)" %
                         ((not dumb) and 'not-' or '',
                          assoc_handle, assoc.expiresIn))
             if checkExpiration:
@@ -1339,7 +1340,7 @@ class Encoder(object):
                                       headers={'location': location})
         elif encode_as == ENCODE_HTML_FORM:
             wr = self.responseFactory(code=HTTP_OK,
-                                      body=response.toFormMarkup())
+                                      body=response.toHTML())
         else:
             # Can't encode this to a protocol message.  You should probably
             # render it to HTML and show it to the user.
@@ -1425,7 +1426,7 @@ class Decoder(object):
 
         try:
             message = Message.fromPostArgs(query)
-        except InvalidOpenIDNamespace, err:
+        except InvalidOpenIDNamespace as err:
             # It's useful to have a Message attached to a ProtocolError, so we
             # override the bad ns value to build a Message out of it.  Kinda
             # kludgy, since it's made of lies, but the parts that aren't lies
@@ -1505,11 +1506,13 @@ class Server(object):
     @type negotiator: L{openid.association.SessionNegotiator}
     """
 
-    signatoryClass = Signatory
-    encoderClass = SigningEncoder
-    decoderClass = Decoder
-
-    def __init__(self, store, op_endpoint=None):
+    def __init__(
+        self,
+        store,
+        op_endpoint=None,
+        signatoryClass=Signatory,
+        encoderClass=SigningEncoder,
+        decoderClass=Decoder):
         """A new L{Server}.
 
         @param store: The back-end where my associations are stored.
@@ -1525,9 +1528,9 @@ class Server(object):
             if you want to respond to any version 2 OpenID requests.
         """
         self.store = store
-        self.signatory = self.signatoryClass(self.store)
-        self.encoder = self.encoderClass(self.signatory)
-        self.decoder = self.decoderClass(self)
+        self.signatory = signatoryClass(self.store)
+        self.encoder = encoderClass(self.signatory)
+        self.decoder = decoderClass(self)
         self.negotiator = default_negotiator.copy()
 
         if not op_endpoint:
