@@ -7,6 +7,7 @@ import string
 import os
 import os.path
 import time
+import logging
 
 from errno import EEXIST, ENOENT
 
@@ -25,7 +26,7 @@ except ImportError:
             name = os.tempnam(dir)
             try:
                 fd = os.open(name, os.O_CREAT | os.O_EXCL | os.O_RDWR, 0600)
-            except OSError, why:
+            except OSError as why:
                 if why.errno != EEXIST:
                     raise
             else:
@@ -82,7 +83,7 @@ def _removeIfPresent(filename):
     """
     try:
         os.unlink(filename)
-    except OSError, why:
+    except OSError as why:
         if why.errno == ENOENT:
             # Someone beat us to it, but it's gone, so that's OK
             return 0
@@ -102,7 +103,7 @@ def _ensureDir(dir_name):
     """
     try:
         os.makedirs(dir_name)
-    except OSError, why:
+    except OSError as why:
         if why.errno != EEXIST or not os.path.isdir(dir_name):
             raise
 
@@ -220,7 +221,7 @@ class FileOpenIDStore(OpenIDStore):
 
             try:
                 os.rename(tmp, filename)
-            except OSError, why:
+            except OSError as why:
                 if why.errno != EEXIST:
                     raise
 
@@ -229,7 +230,7 @@ class FileOpenIDStore(OpenIDStore):
                 # file, but not in putting the temporary file in place.
                 try:
                     os.unlink(filename)
-                except OSError, why:
+                except OSError as why:
                     if why.errno == ENOENT:
                         pass
                     else:
@@ -289,7 +290,7 @@ class FileOpenIDStore(OpenIDStore):
     def _getAssociation(self, filename):
         try:
             assoc_file = file(filename, 'rb')
-        except IOError, why:
+        except IOError as why:
             if why.errno == ENOENT:
                 # No association exists for that URL and handle
                 return None
@@ -351,7 +352,7 @@ class FileOpenIDStore(OpenIDStore):
         filename = os.path.join(self.nonce_dir, filename)
         try:
             fd = os.open(filename, os.O_CREAT | os.O_EXCL | os.O_WRONLY, 0200)
-        except OSError, why:
+        except OSError as why:
             if why.errno == EEXIST:
                 return False
             else:
@@ -369,9 +370,9 @@ class FileOpenIDStore(OpenIDStore):
         for association_filename in association_filenames:
             try:
                 association_file = file(association_filename, 'rb')
-            except IOError, why:
+            except IOError as why:
                 if why.errno == ENOENT:
-                    oidutil.log("%s disappeared during %s._allAssocs" % (
+                    logging.exception("%s disappeared during %s._allAssocs" % (
                         association_filename, self.__class__.__name__))
                 else:
                     raise
@@ -399,8 +400,8 @@ class FileOpenIDStore(OpenIDStore):
 
         () -> NoneType
         """
-        cleanupAssociations()
-        cleanupNonces()
+        self.cleanupAssociations()
+        self.cleanupNonces()
 
     def cleanupAssociations(self):
         removed = 0
