@@ -24,7 +24,8 @@ generateSecret = randomString
 
 def getTmpDbName():
     hostname = socket.gethostname()
-    hostname.replace('.', '_')
+    hostname = hostname.replace('.', '_')
+    hostname = hostname.replace('-', '_')
     return "%s_%d_%s_openid_test" % \
            (hostname, os.getpid(), \
             random.randrange(1, int(time.time())))
@@ -233,6 +234,7 @@ def test_filestore():
     store = filestore.FileOpenIDStore(temp_dir)
     try:
         testStore(store)
+        store.cleanup()
     except:
         raise
     else:
@@ -264,7 +266,15 @@ def test_mysql():
         from MySQLdb.constants import ER
 
         # Change this connect line to use the right user and password
-        conn = MySQLdb.connect(user=db_user, passwd=db_passwd, host = db_host)
+        try:
+            conn = MySQLdb.connect(user=db_user, passwd=db_passwd, host = db_host)
+        except MySQLdb.OperationalError as why:
+            if why[0] == 2005:
+                print ('Skipping MySQL store test (cannot connect '
+                       'to test server on host %r)' % (db_host,))
+                return
+            else:
+                raise
 
         conn.query('CREATE DATABASE %s;' % db_name)
         try:
