@@ -370,7 +370,7 @@ class TestQueryFormat(TestIdRes):
         query = {'openid.mode': ['cancel']}
         try:
             r = Message.fromPostArgs(query)
-        except TypeError, err:
+        except TypeError as err:
             self.failUnless(str(err).find('values') != -1, err)
         else:
             self.fail("expected TypeError, got this instead: %s" % (r,))
@@ -506,7 +506,7 @@ class TestCompleteMissingSig(unittest.TestCase, CatchLogs):
              'assoc_handle': 'does not matter',
              'sig': GOODSIG,
              'response_nonce': mkNonce(),
-             'signed': 'identity,return_to,response_nonce,assoc_handle,claimed_id',
+             'signed': 'identity,return_to,response_nonce,assoc_handle,claimed_id,op_endpoint',
              'claimed_id': claimed_id,
              'op_endpoint': self.server_url,
              'ns':OPENID2_NS,
@@ -534,7 +534,7 @@ class TestCompleteMissingSig(unittest.TestCase, CatchLogs):
         self.message.delArg(OPENID_NS, 'identity')
         self.message.delArg(OPENID_NS, 'claimed_id')
         self.endpoint.claimed_id = None
-        self.message.setArg(OPENID_NS, 'signed', 'return_to,response_nonce,assoc_handle')
+        self.message.setArg(OPENID_NS, 'signed', 'return_to,response_nonce,assoc_handle,op_endpoint')
         r = self.consumer.complete(self.message, self.endpoint, None)
         self.failUnlessSuccess(r)
 
@@ -672,7 +672,7 @@ class TestSetupNeeded(TestIdRes):
     def failUnlessSetupNeeded(self, expected_setup_url, message):
         try:
             self.consumer._checkSetupNeeded(message)
-        except SetupNeededError, why:
+        except SetupNeededError as why:
             self.failUnlessEqual(expected_setup_url, why.user_setup_url)
         else:
             self.fail("Expected to find an immediate-mode response")
@@ -767,7 +767,7 @@ class IdResCheckForFieldsTest(TestIdRes):
          'op_endpoint':'my favourite server',
          'response_nonce':'use only once',
          },
-        ['return_to', 'response_nonce', 'assoc_handle'])
+        ['return_to', 'response_nonce', 'assoc_handle', 'op_endpoint'])
 
     test_openid2Success_identifiers = mkSuccessTest(
         {'ns':OPENID2_NS,
@@ -780,48 +780,67 @@ class IdResCheckForFieldsTest(TestIdRes):
          'response_nonce':'use only once',
          },
         ['return_to', 'response_nonce', 'identity',
-         'claimed_id', 'assoc_handle'])
+         'claimed_id', 'assoc_handle', 'op_endpoint'])
 
-    def mkFailureTest(openid_args, signed_list):
+    def mkMissingFieldTest(openid_args):
         def test(self):
             message = Message.fromOpenIDArgs(openid_args)
             try:
                 self.consumer._idResCheckForFields(message)
-            except ProtocolError, why:
+            except ProtocolError as why:
                 self.failUnless(why[0].startswith('Missing required'))
             else:
                 self.fail('Expected an error, but none occurred')
         return test
 
-    test_openid1Missing_returnToSig = mkFailureTest(
+    def mkMissingSignedTest(openid_args):
+        def test(self):
+            message = Message.fromOpenIDArgs(openid_args)
+            try:
+                self.consumer._idResCheckForFields(message)
+            except ProtocolError as why:
+                self.failUnless(why[0].endswith('not signed'))
+            else:
+                self.fail('Expected an error, but none occurred')
+        return test
+
+    test_openid1Missing_returnToSig = mkMissingSignedTest(
         {'return_to':'return',
          'assoc_handle':'assoc handle',
          'sig':'a signature',
          'identity':'someone',
-         },
-        ['identity'])
+         'signed':'identity',
+         })
 
-    test_openid1Missing_identitySig = mkFailureTest(
+    test_openid1Missing_identitySig = mkMissingSignedTest(
         {'return_to':'return',
          'assoc_handle':'assoc handle',
          'sig':'a signature',
          'identity':'someone',
-         },
-        ['return_to'])
+         'signed':'return_to'
+         })
 
-    test_openid1MissingReturnTo = mkFailureTest(
+    test_openid2Missing_opEndpointSig = mkMissingSignedTest(
+        {'ns':OPENID2_NS,
+         'return_to':'return',
+         'assoc_handle':'assoc handle',
+         'sig':'a signature',
+         'identity':'someone',
+         'op_endpoint':'the endpoint',
+         'signed':'return_to,identity,assoc_handle'
+         })
+
+    test_openid1MissingReturnTo = mkMissingFieldTest(
         {'assoc_handle':'assoc handle',
          'sig':'a signature',
          'identity':'someone',
-         },
-        ['return_to', 'identity'])
+         })
 
-    test_openid1MissingAssocHandle = mkFailureTest(
+    test_openid1MissingAssocHandle = mkMissingFieldTest(
         {'return_to':'return',
          'sig':'a signature',
          'identity':'someone',
-         },
-        ['return_to', 'identity'])
+         })
 
     # XXX: I could go on...
 
@@ -1457,7 +1476,7 @@ class ConsumerTest(unittest.TestCase):
         def test():
             try:
                 self.consumer.begin('unused in this test')
-            except DiscoveryFailure, why:
+            except DiscoveryFailure as why:
                 self.failUnless(why[0].startswith('Error fetching'))
                 self.failIf(why[0].find('Unit test') == -1)
             else:
@@ -1473,7 +1492,7 @@ class ConsumerTest(unittest.TestCase):
         def test():
             try:
                 self.consumer.begin(url)
-            except DiscoveryFailure, why:
+            except DiscoveryFailure as why:
                 self.failUnless(why[0].startswith('No usable OpenID'))
                 self.failIf(why[0].find(url) == -1)
             else:
@@ -1747,12 +1766,12 @@ class TestDiscoveryVerification(unittest.TestCase):
         self.services = [endpoint]
         try:
             r = self.consumer._verifyDiscoveryResults(self.message, endpoint)
-        except ProtocolError, e:
+        except ProtocolError as e:
             # Should we make more ProtocolError subclasses?
             self.failUnless(str(e), text)
         else:
             self.fail("expected ProtocolError, %r returned." % (r,))
-            
+
 
     def test_foreignDelegate(self):
         text = "verify failed"
@@ -1774,7 +1793,7 @@ class TestDiscoveryVerification(unittest.TestCase):
 
         try:
             r = self.consumer._verifyDiscoveryResults(self.message, endpoint)
-        except ProtocolError, e:
+        except ProtocolError as e:
             self.failUnlessEqual(str(e), text)
         else:
             self.fail("Exepected ProtocolError, %r returned" % (r,))
@@ -2055,7 +2074,7 @@ class TestKVPost(unittest.TestCase):
         response.body = "error:bonk\nerror_code:7\n"
         try:
             r = _httpResponseToMessage(response, self.server_url)
-        except ServerError, e:
+        except ServerError as e:
             self.failUnlessEqual(e.error_text, 'bonk')
             self.failUnlessEqual(e.error_code, '7')
         else:
